"use strict";
/**
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * @format
 */
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Dump a section of the native visual tree.
 */
async function dumpVisualTree(accessibilityId, opts) {
    if (!automationClient) {
        throw new Error('RPC client is not enabled');
    }
    const dumpResponse = await automationClient.invoke('DumpVisualTree', {
        accessibilityId,
        ...opts,
    });
    if (dumpResponse.type === 'error') {
        throw new Error(dumpResponse.message);
    }
    const element = dumpResponse.result;
    if ((opts === null || opts === void 0 ? void 0 : opts.pruneCollapsed) !== false) {
        pruneCollapsedElements(element);
    }
    if ((opts === null || opts === void 0 ? void 0 : opts.deterministicOnly) !== false) {
        removeNonDeterministicProps(element);
    }
    return element;
}
exports.default = dumpVisualTree;
/**
 * Removes trees of XAML that are not visible.
 */
function pruneCollapsedElements(element) {
    if (!element.children) {
        return;
    }
    element.children = element.children.filter(child => child.Visibility !== 'Collapsed');
    element.children.forEach(pruneCollapsedElements);
}
/**
 * Removes trees of properties that are not determinisitc
 */
function removeNonDeterministicProps(element) {
    if (element.RenderSize) {
        // RenderSize is subject to rounding, etc and should mostly be derived from
        // other deterministic properties in the tree.
        delete element.RenderSize;
    }
    if (element.children) {
        element.children.forEach(removeNonDeterministicProps);
    }
}
//# sourceMappingURL=dumpVisualTree.js.map